@@ -124,14 +124,14 @@ class BaseUI():
         return value
 
     def edit_account(self, treeview):
-        uid = self.get_selected_item(treeview, 0)
+        key_id = self.get_selected_item(treeview, 0)
         # pop up the account dialog
 
         self.accounts_model.get_accounts()
 
     def delete_account(self, treeview):
-        uid = self.get_selected_item(treeview, 0)
-        self.controller.settings.remove_account(uid)
+        key_id = self.get_selected_item(treeview, 0)
+        self.controller.settings.remove_account(key_id)
         # refresh model
         self.accounts_model.get_accounts()
 
@@ -139,8 +139,8 @@ class BaseUI():
     def add_columns_to_accounts(self, treeview):
         #Column 0 for the treeview
         renderer = gtk.CellRendererText()
-        column = gtk.TreeViewColumn('User ID', renderer, 
-                text=models.AccountsModel.C_UID)
+        column = gtk.TreeViewColumn('Key ID', renderer, 
+                text=models.AccountsModel.C_KID)
         column.set_property("expand", True)
         treeview.append_column(column)
 
@@ -160,23 +160,23 @@ class BaseUI():
         dialog.set_transient_for(window)
         dialog.set_title("New Account")
 
-        uidLabel = gtk.Label("User ID:")
-        uidLabel.set_justify(gtk.JUSTIFY_LEFT)
-        vbox.add(uidLabel)
+        key_idLabel = gtk.Label("Key ID:")
+        key_idLabel.set_justify(gtk.JUSTIFY_LEFT)
+        vbox.add(key_idLabel)
         
-        uidEntry = gtk.Entry()
-        uidEntry.set_property('is_focus', False)
+        key_idEntry = gtk.Entry()
+        key_idEntry.set_property('is_focus', False)
         
-        vbox.add(uidEntry)
+        vbox.add(key_idEntry)
 
-        apiLabel = gtk.Label("API key:")
-        apiLabel.set_justify(gtk.JUSTIFY_LEFT)
-        vbox.add(apiLabel)
+        verCodeLabel = gtk.Label("Verification code:")
+        verCodeLabel.set_justify(gtk.JUSTIFY_LEFT)
+        vbox.add(verCodeLabel)
         
-        apiEntry = gtk.Entry()
-        apiEntry.set_property('is_focus', False)
+        verCodeEntry = gtk.Entry()
+        verCodeEntry.set_property('is_focus', False)
 
-        vbox.add(apiEntry)
+        vbox.add(verCodeEntry)
        
         ok_button = dialog.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
         cancel_button = dialog.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
@@ -188,18 +188,18 @@ class BaseUI():
 
         while not valid_credentials:
             if result == gtk.RESPONSE_OK:
-                uid = uidEntry.get_text()
-                api_key = apiEntry.get_text()
+                key_id = key_idEntry.get_text()
+                ver_code = verCodeEntry.get_text()
             
                 try:
-                    validation.validate_uid(uid)
-                    validation.validate_api_key(api_key)
+                    validation.validate_key_id(key_id)
+                    validation.validate_ver_code(ver_code)
                 except validation.ValidationError, e:
                     self.report_error(e.message)
                     result = dialog.run()
                 else:
                     valid_credentials = True
-                    self.controller.settings.add_account(uid, api_key)
+                    self.controller.settings.add_account(key_id, ver_code)
                     self.accounts_model.get_accounts()
             else:
                 break
@@ -244,7 +244,11 @@ class mEveMonUI(BaseUI):
         self.win.connect("destroy", self.controller.quit)
         self.win.show_all()
 
-        # wait notification start --danny
+        wait_anim = hildon.hildon_banner_show_animation(self.win, None, "Loading overview...")        
+        # it would seem that on diablo we have to wait for gtk to
+        # get its ass in gear...
+        while gtk.events_pending():
+            gtk.main_iteration()
 
         # Create menu
         menu = self.create_menu(self.win)
@@ -252,7 +256,6 @@ class mEveMonUI(BaseUI):
         # Attach menu to the window
         self.win.set_menu(menu)
 
-
         # create the treeview --danny
         self.char_model = models.CharacterListModel(self.controller)
         treeview = gtk.TreeView(model = self.char_model)
@@ -265,7 +268,7 @@ class mEveMonUI(BaseUI):
         self.win.add_with_scrollbar(treeview)
         self.win.show_all()
 
-        # wait notification end --danny
+        wait_anim.destroy()
 
     def add_columns_to_treeview(self, treeview):
         #Column 0 for the treeview
@@ -283,9 +286,13 @@ class mEveMonUI(BaseUI):
         column.set_property("expand", True)
         treeview.append_column(column)
  
-    def refresh_clicked(self, button):
+    def refresh_clicked(self, button, window):
+        wait_anim = hildon.hildon_banner_show_animation(self.win, None, "Refreshing view...")        
+        # let gtk catch up...
+        while gtk.events_pending():
+            gtk.main_iteration()
         self.char_model.get_characters()
-        # wait notification end --danny
+        wait_anim.destroy()
 
     def do_charactersheet(self, treeview, path, view_column):
 
@@ -294,10 +301,10 @@ class mEveMonUI(BaseUI):
         
         # column 0 is the portrait, column 1 is name
         char_name = model.get_value(miter, 1)
-        uid = model.get_value(miter, 2)
+        key_id = model.get_value(miter, 2)
         
-        if uid:
-            CharacterSheetUI(self.controller, char_name, uid)
+        if key_id:
+            CharacterSheetUI(self.controller, char_name, key_id)
         else:
             pass
 
@@ -305,10 +312,10 @@ class CharacterSheetUI(BaseUI):
     #time between live sp updates (in milliseconds)
     UPDATE_INTERVAL = 1000
 
-    def __init__(self, controller, char_name, uid):
+    def __init__(self, controller, char_name, key_id):
         self.controller = controller
         self.char_name = char_name
-        self.uid = uid
+        self.key_id = key_id
         self.sheet = None
         self.char_id = None
         self.skills_model = None
@@ -322,7 +329,10 @@ class CharacterSheetUI(BaseUI):
 
         self.win.show_all() 
 
-        # wait notification start --danny
+        wait_anim = hildon.hildon_banner_show_animation(self.win, None, "Loading character sheet...")        
+        # let gtk catch up...
+        while gtk.events_pending():
+            gtk.main_iteration()
 
         # Create menu
         # NOTE: we probably want a window-specific menu for this page, but the
@@ -333,7 +343,7 @@ class CharacterSheetUI(BaseUI):
 
         self.char_id = self.controller.char_name2id(self.char_name)
 
-        self.sheet = self.controller.get_char_sheet(self.uid, self.char_id)
+        self.sheet = self.controller.get_char_sheet(self.key_id, self.char_id)
 
         self.win.set_title(self.char_name)
 
@@ -380,7 +390,7 @@ class CharacterSheetUI(BaseUI):
         self.win.add_with_scrollbar(vbox)
         self.win.show_all()
 
-        # wait notification end --danny
+        wait_anim.destroy()
         
         # diablo doesnt have a glib module, but gobject module seems to have
         # the same functions...
@@ -392,7 +402,7 @@ class CharacterSheetUI(BaseUI):
         gtk.Window.destroy(self.win)
 
     def display_skill_in_training(self, vbox):
-        skill = self.controller.get_skill_in_training(self.uid, self.char_id)
+        skill = self.controller.get_skill_in_training(self.key_id, self.char_id)
         
         if skill.skillInTraining:
 
@@ -436,11 +446,11 @@ class CharacterSheetUI(BaseUI):
         self.add_label("<small><b>Balance:</b> %s ISK</small>" % 
                 util.comma(self.sheet.balance), box)
 
-        self.live_sp_val = self.controller.get_sp(self.uid, self.char_id)
+        self.live_sp_val = self.controller.get_sp(self.key_id, self.char_id)
         self.live_sp = self.add_label("<small><b>Total SP:</b> %s</small>" %
                 util.comma(int(self.live_sp_val)), box)
         
-        self.spps = self.controller.get_spps(self.uid, self.char_id)[0]
+        self.spps = self.controller.get_spps(self.key_id, self.char_id)[0]
 
 
     def fill_stats(self, box):
@@ -479,9 +489,13 @@ class CharacterSheetUI(BaseUI):
         treeview.append_column(column)
 
 
-    def refresh_clicked(self, button):
+    def refresh_clicked(self, button, window):
+        wait_anim = hildon.hildon_banner_show_animation(self.win, None, "Loading overview...")        
+        # let gtk catch up...
+        while gtk.events_pending():
+            gtk.main_iteration()
         self.skills_model.get_skills()
-        # wait notification end --danny
+        wait_anim.destroy()
 
     def update_live_sp(self):
         self.live_sp_val = self.live_sp_val + self.spps * (self.UPDATE_INTERVAL / 1000)
